#coding=utf-8
#DESC:Show selected residue as ball

import tempfile
import shutil
from molFeat import *


def run():

  # ボールの半径
  BALLRADIUS = 40
  # ボールの色　Red/Green/Blueを1.0～0.0の値で指定可能
  RGB = [0.0, 1.0, 0.0]


  curMols = getCurrentMolecule()        # 選択中の分子を取得
  selects = []                          # 選択原子のbool値を格納するリスト
  coord = []                            # ボールを置く座標のリスト

  # 選択原子のbool値の取得
  for i in range(len(curMols)):
    selects.append(getAtomSelected())

  # 選択中の分子数分ループ
  for i in range(len(curMols)):

    numAtoms = getNumAtoms(curMols[i])  # 原子数を取得
    j = 0

    # 原子数分ループ
    while j < numAtoms:
      start = j # 原子のindex(残基の開始位置)
      end   = j # 原子のindex(残基の終了位置)
      seqNo = getAtomGroupSequenceNo(curMols[i], j)
      tmpNo = seqNo
      select= False
      
      # 残基番号が変わるとwhileを抜ける
      while seqNo == tmpNo and j < numAtoms:
        # 残基に1つでも選択原子があればselect=Trueとみなす
        if selects[i][j]:
          select = True
        # 原子番号を増分
        j += 1
        seqNo = getAtomGroupSequenceNo(curMols[i], j)
      
      end = j - 1
      
      # select=Trueの時、ボールを置く残基として座標をcoordに格納する
      if select:
        # 残基の原子全てを選択状態に変更
        setCurrentMolecule([curMols[i]])
        selectStr ="atomidx:" + str(start) + "-" + str(end)
        selectAtom(selectStr)
        # 重心座標を取得し、ボールを置く座標のリストに格納
        coord.append(getAtomTranslation())
        print "Sequece no：  " + str(seqNo)
        print "Selected atoms：  " + str(selectStr)
        print "Center of reidue：  " + str(getAtomTranslation())
        print "\n"


  # 一時フォルダのpdbに座標を書き出し
  tmpDir = tempfile.mkdtemp()
  fileName = tmpDir + "/ball.pdb"
  f1 = open(fileName, 'w')
  for i in range(len(coord)):
    f1.write("HETATM%4d  C   BAL A   1    %8.3f%8.3f%8.3f  1.00  0.0            C  \n" % (i, coord[i][0], coord[i][1], coord[i][2]))
  f1.close()

  # 一時ファイルの読込と形状・色の設定
  importFile(fileName)
  shutil.rmtree(tmpDir)
  setAtomShape(SHAPE_BALL, True)
  setBallRadius(BALLRADIUS)
  setAtomColorMode(COLOR_USER)
  setAtomUserColor(RGB)


if __name__ == '__main__':
	run()
